FilterLowshRNAs <- function(AchillesFile1, extension, AchillesFile2 = NULL, AchillesFile3 = NULL) {
  
  #read in Achilles File
  print("Reading in First File")
  Achilles1 <- read_gct(AchillesFile1)
  #obtain shRNA sequences
  Achilles1shRNAs <- Achilles1[,1]
  
  #obtain column names, mean of DNA levels, and assign NaN to low shRNAs for ACHILLES1FILE
  shRNAData <- shRNAdataAchilles(Achilles1)
  colNames1 <- shRNAData$colNames
  meanDNA1 <- shRNAData$meanDNA
  LowAchilles1 <- shRNAData$LowAchilles
  print("Finished assigning NaN to low shRNAs")
  
  #change NA and NaN in Description column to empty strings
  LowAchilles1[is.nan(Achilles1[,"Description"]),"Description"] <- ""
  LowAchilles1[is.na(Achilles1[,"Description"]),"Description"] <- ""
  removedAchilles <- LowAchilles1
  
  #make matrix with repeating meanDNA1 for all cell lines (same dimensions as Achilles1)
  print("Starting to make DNArefs matrix")
  DNAreferences1 <- matrix(rep(meanDNA1, dim(Achilles1)[2]-2), ncol=dim(Achilles1)[2]-2, byrow = FALSE)
  #Concatenate shRNA sequences(Name column), Description column, with DNAreferences
  DNAreferences1 <- cbind(Achilles1shRNAs, Achilles1[,2], DNAreferences1)
  #assign column names to DNAreferences
  colnames(DNAreferences1) <- colNames1
  print("Finished DNArefs matrix")
  
  removedDNAreferences <- DNAreferences1
  
  #check to see if user inputted a second file
  if (!is.null(AchillesFile2)){
    print("Yes, there is a second file.")
    #read in Achilles File
    Achilles2 <- read_gct(AchillesFile2)
    #remove description column 
    Achilles2 <- Achilles2[,-which(names(Achilles2) %in% c("Description"))]
    
    #check for identical shRNA sequences in both files
    Achilles2shRNAs <- Achilles2[,1]
    diff <- setdiff(Achilles1shRNAs, Achilles2shRNAs)
    if (length(diff) != 0){
      stop("The shNRAs in the files are not identical.")
    }
    else{
      print("The shRNAs in the files are identical.")
    }
    
    #obtain column names, mean of DNA levels, and assign NaN to low shRNAs for ACHILLES2FILE
    shRNAData <- shRNAdataAchilles(Achilles2)
    colNames2 <- shRNAData$colNames
    meanDNA2 <- shRNAData$meanDNA
    LowAchilles2 <- shRNAData$LowAchilles
    print("set low shRNAs to NaN and beginning to combine to matrices")
    #merge two Achilles datasets by shRNA sequence in Name column
    combinedAchilles <- merge(LowAchilles1, LowAchilles2, by="Name")
    print("finished combining matrices")
    
    #find indices of combinedAchilles where the shRNA is NaN in both datasets
    print("starting to find indices where NaN in whole row")
    #in order to use is.nan: remove Name and Description column to make combinedAchilles a matrix
    RowIndicesNaN <- rowSums(is.nan(as.matrix(combinedAchilles[,-which(names(combinedAchilles) %in% c("Name","Description"))]))) < ncol(combinedAchilles)-2
    print("starting to remove rows")
    #remove rows with all NaNs from combinedAchilles
    removedAchilles <- combinedAchilles[RowIndicesNaN, ]
    #removedAchilles <- format(removedAchilles, digits = 6)
    print("finished removing rows")
    
    print("starting to make DNA references matrix")
    #make matrix with repeating meanDNA2 for all cell lines (same dimensions as Achilles1)
    DNAreferences2 <- matrix(rep(meanDNA2, dim(Achilles2)[2]-1), ncol = dim(Achilles2)[2]-1, byrow = FALSE)
    #Concatenate shRNA sequences(Name column), Description column, with DNAreferences
    DNAreferences2 <- cbind(Achilles2shRNAs, DNAreferences2)
    #assign column names to DNAreferences
    colnames(DNAreferences2) <- colNames2
    
    print("Combining DNA reference matrices")
    combinedDNAreferences <- cbind(DNAreferences1[order(DNAreferences1[,"Name"]),],DNAreferences2[order(DNAreferences2[,"Name"]),])
      
    #remove duplicate name column
    NameIndex <- grep("Name",colnames(combinedDNAreferences))[2]
    combinedDNAreferences <- combinedDNAreferences[,-NameIndex]
    combinedDNAreferences[is.na(combinedDNAreferences[,"Description"]),"Description"] <- ""
    
    #remove rows where DNA level is low
    removedDNAreferences <- combinedDNAreferences[RowIndicesNaN, ]
    #removedDNAreferences <- format(removedDNAreferences, digits = 6)
    
  }
  
  #check to see if user inputted a third file
  if (!is.null(AchillesFile3)){
    print("Yes, there is a third file.")
    Achilles3 <- read_gct(AchillesFile3)
    Achilles3 <- Achilles3[,-which(names(Achilles3) %in% c("Description"))]
    
    #check for identical shRNA sequences in all 3 files
    Achilles3shRNAs <- Achilles3[,1]
    diff13 <- setdiff(Achilles1shRNAs, Achilles3shRNAs)
    diff23 <- setdiff(Achilles2shRNAs, Achilles3shRNAs)
    if (length(diff13) != 0 && length(diff23) != 0){
      stop("The shNRAs in the files are not identical.")
    }
    else{
      print("The shRNAs in the files are identical.")
    }
    
    #obtain column names, mean of DNA levels, and assign NaN to low shRNAs for ACHILLES3FILE
    shRNAData <- shRNAdataAchilles(Achilles3)
    colNames3 <- shRNAData$colNames
    meanDNA3 <- shRNAData$meanDNA
    LowAchilles3 <- shRNAData$LowAchilles
    print("Finished setting NaN to low shRNAs")
    
    print("Beginning to merge datasets")
    #merge three Achilles datasets by shRNA sequence in Name column
    combinedAchilles <- merge(combinedAchilles, LowAchilles3, by="Name")
    print("Finished merging datasets")
    
    #find indices of combinedAchilles where the shRNA is NaN in all 3 datasets
    print("Finding indices")
    #in order to use is.nan: remove Name and Description column to make combinedAchilles a matrix
    RowIndicesNaN <- rowSums(is.nan(as.matrix(combinedAchilles[,-which(names(combinedAchilles) %in% c("Name","Description"))]))) < ncol(combinedAchilles)-2
    
    print("starting to remove rows with all NaNs")
    #remove rows with all NaNs from combinedAchilles
    removedAchilles <- combinedAchilles[RowIndicesNaN, ]
    #removedAchilles <- format(removedAchilles, digits = 6)
    
    #make matrix with repeating meanDNA3 for all cell lines (same dimensions as Achilles3)
    DNAreferences3 <- matrix(rep(meanDNA3, dim(Achilles3)[2]-1), ncol = dim(Achilles3)[2]-1, byrow = FALSE)
    #Concatenate shRNA sequences(Name column), Description column, with DNAreferences
    DNAreferences3 <- cbind(Achilles3shRNAs, DNAreferences3)
    #assign column names to DNAreferences
    colnames(DNAreferences3) <- colNames3
    
    print("Combining DNA reference matrices")
    combinedDNAreferences <- cbind(combinedDNAreferences[order(combinedDNAreferences[,"Name"]),],DNAreferences3[order(DNAreferences3[,"Name"]),])
    
    #remove duplicate name column
    NameIndex <- grep("Name",colnames(combinedDNAreferences))[2]
    combinedDNAreferences <- combinedDNAreferences[,-NameIndex]
    combinedDNAreferences[is.na(combinedDNAreferences[,"Description"]),"Description"] <- ""
    
    #remove rows where DNA level is low
    removedDNAreferences <- combinedDNAreferences[RowIndicesNaN, ]
    #removedDNAreferences <- format(removedDNAreferences, digits = 6)
    
  }
  
  #write removedDNAreferences and removedAchilles to GCT file
  writeGCTresults(removedDNAreferences, "DNAreferences_filtered.rnai.gct", extension)
  writeGCTresults(format(removedAchilles,digits=6), "Achilles_filtered.rnai.gct", extension)
  #return(removedDNAreferences)

}

